@@ -2,6 +2,7 @@ package RT::Attachment;
 
 use strict;
 use RTx::Shredder::Exceptions;
+use RTx::Shredder::Constants;
 use RTx::Shredder::Dependencies;
 
 
@@ -9,8 +10,7 @@ sub Dependencies
 {
 	my $self = shift;
 	my %args = (
-			Cached => undef,
-			Strength => 'DependsOn',
+			Flags => DEPENDS_ON,
 			@_,
 		   );
 
@@ -18,7 +18,7 @@ sub Dependencies
 		RTx::Shredder::Exception->throw('Object is not loaded');
 	}
 
-	my $deps = $args{'Cached'} || RTx::Shredder::Dependencies->new();
+	my $deps = RTx::Shredder::Dependencies->new();
 
 # No dependencies that should be deleted with record
 
