@@ -1,6 +1,7 @@
 package RT::CustomField;
 
 use strict;
+use RTx::Shredder::Constants;
 use RTx::Shredder::Exceptions;
 use RTx::Shredder::Dependencies;
 
@@ -8,8 +9,7 @@ sub Dependencies
 {
 	my $self = shift;
 	my %args = (
-			Cached => undef,
-			Strength => 'DependsOn',
+			Flags => DEPENDS_ON,
 			@_,
 		   );
 
@@ -17,19 +17,25 @@ sub Dependencies
 		RTx::Shredder::Exception->throw('Object is not loaded');
 	}
 
-	my $deps = $args{'Cached'} || RTx::Shredder::Dependencies->new();
+	my $deps = RTx::Shredder::Dependencies->new();
+	my $list = [];
 
 # Custom field values
-	my $objs = $self->Values;
-	$deps->_PushDependencies( $self, 'DependsOn', $objs );
+	push( @$list, $self->Values );
 
 # Ticket custom field values
-	$objs = RT::TicketCustomFieldValues->new( $self->CurrentUser );
+	my $objs = RT::TicketCustomFieldValues->new( $self->CurrentUser );
 	$objs->LimitToCustomField( $self->Id );
-	$deps->_PushDependencies( $self, 'DependsOn', $objs );
+	push( @$list, $objs );
 
 #TODO: Queues if we wish export tool
 
+	$deps->_PushDependencies(
+			BaseObj => $self,
+			Flags => DEPENDS_ON,
+			TargetObjs => $list,
+			Shredder => $args{'Shredder'}
+		);
 	return $deps;
 }
 
